from plotly.graph_objs import Waterfall

from plotly.graph_objs import Volume

from plotly.graph_objs import Violin

from plotly.graph_objs import Table

from plotly.graph_objs import Surface

from plotly.graph_objs import Sunburst

from plotly.graph_objs import Streamtube

from plotly.graph_objs import Splom

from plotly.graph_objs import Scatterternary

from plotly.graph_objs import Scatter

from plotly.graph_objs import Scatterpolar

from plotly.graph_objs import Scatterpolargl

from plotly.graph_objs import Scattermapbox

from plotly.graph_objs import Scattergl

from plotly.graph_objs import Scattergeo

from plotly.graph_objs import Scattercarpet

from plotly.graph_objs import Scatter3d

from plotly.graph_objs import Sankey

from plotly.graph_objs import Pointcloud

from plotly.graph_objs import Pie

from plotly.graph_objs import Parcoords

from plotly.graph_objs import Parcats

from plotly.graph_objs import Ohlc

from plotly.graph_objs import Mesh3d

from plotly.graph_objs import Isosurface

from plotly.graph_objs import Histogram

from plotly.graph_objs import Histogram2d

from plotly.graph_objs import Histogram2dContour

from plotly.graph_objs import Heatmap

from plotly.graph_objs import Heatmapgl

from plotly.graph_objs import Funnel

from plotly.graph_objs import Funnelarea

from plotly.graph_objs import Contour

from plotly.graph_objs import Contourcarpet

from plotly.graph_objs import Cone

from plotly.graph_objs import Choropleth

from plotly.graph_objs import Carpet

from plotly.graph_objs import Candlestick

from plotly.graph_objs import Box

from plotly.graph_objs import Bar

from plotly.graph_objs import Barpolar

from plotly.graph_objs import Area
